==> hinemos_src-3.2.1.tar.gz: HinemosManager/src_calendar/com/clustercontrol/calendar/ejb/entity/CalendarWeekdayInfoBean.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.calendar.ejb.entity;

import java.sql.Time;
import java.util.Date;
import java.util.Set;

import javax.ejb.FinderException;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 *
 * <!-- begin-user-doc --> カレンダーの曜日別実行規則情報のEntityBean '<em><b>CalendarWeekdayInfoBean</b></em>'. <!-- end-user-doc --> *
 *
 * <!-- begin-xdoclet-definition -->
 * @ejb.bean name="CalendarWeekdayInfo"
 *    jndi-name="CalendarWeekdayInfo"
 *    type="CMP" 
 *    view-type="local"
 *    schema="CalendarWeekdayInfo" 
 *    cmp-version="2.x"
 *    data-source="java:/HinemosDS"
 * 
 * @ejb.persistence 
 *    table-name="cc_cal_weekday_info" 
 * 
 * @ejb.pk
 *    class="com.clustercontrol.calendar.ejb.entity.CalendarWeekdayInfoPK"
 * 
 * @jboss.persistence
 *    datasource="java:/HinemosDS"
 *    datasource-mapping="PostgreSQL 8.0"
 *    table-name="public.cc_cal_weekday_info"
 *    create-table="false"
 *    remove-table="false"
 *    alter-table="false"
 * 
 * @jboss.container-configuration
 *    name="Hinemos Config CMP 2.x EntityBean"
 * 
 * @jboss.depends
 *    name="jboss.jca:service=DataSourceBinding,name=HinemosDS"
 * 
 * @ejb.permission
 *    unchecked="true"
 * 
 * @jboss.method-attributes
 *    pattern="get*"
 *    read-only="true"
 * 
 * @ejb.finder 
 *    query="SELECT OBJECT(a) FROM CalendarWeekdayInfo as a"  
 *    signature="java.util.Collection findAll()"  
 * 
 * @ejb.finder 
 *    query="SELECT OBJECT(a) FROM CalendarWeekdayInfo as a WHERE a.calendar_id = ?1"  
 *    signature="java.util.Collection findByCalendarId(java.lang.String calendarId)"  
 * 
 * @ejb.finder 
 *    query="SELECT OBJECT(a) FROM CalendarWeekdayInfo as a WHERE a.calendar_id = ?1 AND a.weekday = ?2"  
 *    signature="java.util.Collection findByWeekday(java.lang.String calendarId, java.lang.Integer weekday)"  
 * 
 * @ejb.finder 
 *    query="SELECT OBJECT(a) FROM CalendarWeekdayInfo as a WHERE a.calendar_id = ?1 AND a.weekday = ?2 AND ((a.time_from <= ?3 AND a.time_to >= ?3) OR (a.time_from <= ?4 AND a.time_to >= ?4))"  
 *    signature="java.util.Collection findByTimeFromTo(java.lang.String calendarId, java.lang.Integer weekday, java.sql.Time from, java.sql.Time to)"  
 * 
 * @ejb.select
 *    result-type-mapping= "Local" 
 *    method-intf= "LocalHome"
 *    query=""
 *    signature="java.util.Collection ejbSelectGeneric(java.lang.String jbossQL, java.lang.Object[] arg)"
 * @jboss.query
 *    dynamic="true"
 *    signature="java.util.Collection ejbSelectGeneric(java.lang.String jbossQL, java.lang.Object[] arg)"
 * 
 * <!-- end-xdoclet-definition -->
 * @generated
 **/
public abstract class CalendarWeekdayInfoBean implements javax.ejb.EntityBean {
	protected static Log m_log = LogFactory.getLog( CalendarWeekdayInfoBean.class );
	
	/**
	 *
	 * <!-- begin-user-doc -->
	 * The  ejbCreate method.
	 * <!-- end-user-doc -->
	 *
	 * <!-- begin-xdoclet-definition --> 
	 * @ejb.create-method 
	 * <!-- end-xdoclet-definition --> 
	 * @generated
	 */
	public CalendarWeekdayInfoPK ejbCreate(
			String calendar_id, 
			Integer weekday, 
			Time time_from, 
			Time time_to,
			String description, 
			Date reg_date, 
			Date update_date, 
			String reg_user, 
			String update_user
			) throws javax.ejb.CreateException {
		setCalendar_id(calendar_id);
		setWeekday(weekday);
		setDescription(description);
		setTime_from(time_from);
		setTime_to(time_to);
		setReg_date(reg_date);
		setUpdate_date(update_date);
		setReg_user(reg_user);
		setUpdate_user(update_user);
		return null;
	}
	
	
	/**
	 * <!-- begin-user-doc -->
	 * The container invokes this method immediately after it calls ejbCreate.
	 * <!-- end-user-doc -->
	 * 
	 * @generated
	 */
	public void ejbPostCreate() throws javax.ejb.CreateException {
		// begin-user-code
		// end-user-code
	}

	/** 
	 * DynamicQL
	 * 
	 * @param jbossQl JBossQL
	 * @param args query arguments as parameters
	 * 
	 * @jboss.dynamic-ql 
	 */
	public abstract Set ejbSelectGeneric(String jbossQl, Object[] arguments) throws FinderException;
	
	/**
	 *
	 *
	 * <!-- begin-user-doc -->
	 * CMP Field calendar_id
	 *
	 * Returns the calendar_id
	 * @return the calendar_id
	 * 
	 * <!-- end-user-doc -->
	 *
	 * <!-- begin-xdoclet-definition --> 
	 *
	 * @ejb.persistent-field 
	 * @ejb.persistence
	 *    column-name="calendar_id"
	 *     jdbc-type="VARCHAR"
	 *     sql-type="VARCHAR"
	 *     read-only="false"
	 * 
	 * @ejb.pk-field 
	 *
	 * @ejb.interface-method
	 * 
	 * <!-- end-xdoclet-definition --> 
	 * @generated
	 */
	public abstract java.lang.String getCalendar_id();
	
	/**
	 * <!-- begin-user-doc -->
	 * Sets the calendar_id
	 * 
	 * @param java.lang.String the new calendar_id value
	 * <!-- end-user-doc -->
	 * 
	 * <!-- begin-xdoclet-definition --> 
	 * @ejb.interface-method
	 * <!-- end-xdoclet-definition -->
	 * @generated 
	 */
	public abstract void setCalendar_id(java.lang.String calendar_id);
	
	/**
	 *
	 *
	 * <!-- begin-user-doc -->
	 * CMP Field weekday
	 *
	 * Returns the weekday
	 * @return the weekday
	 * 
	 * <!-- end-user-doc -->
	 *
	 * <!-- begin-xdoclet-definition --> 
	 *
	 * @ejb.persistent-field 
	 * @ejb.persistence
	 *    column-name="weekday"
	 *     jdbc-type="SMALLINT"
	 *     sql-type="SMALLINT"
	 *     read-only="false"
	 * 
	 * @ejb.pk-field 
	 *
	 * @ejb.interface-method
	 * 
	 * <!-- end-xdoclet-definition --> 
	 * @generated
	 */
	public abstract java.lang.Integer getWeekday();
	
	/**
	 * <!-- begin-user-doc -->
	 * Sets the weekday
	 * 
	 * @param java.lang.Integer the new weekday value
	 * <!-- end-user-doc -->
	 * 
	 * <!-- begin-xdoclet-definition --> 
	 * @ejb.interface-method
	 * <!-- end-xdoclet-definition -->
	 * @generated 
	 */
	public abstract void setWeekday(java.lang.Integer weekday);

	/**
	 *
	 *
	 * <!-- begin-user-doc -->
	 * CMP Field time_from
	 *
	 * Returns the time_from
	 * @return the time_from
	 * 
	 * <!-- end-user-doc -->
	 *
	 * <!-- begin-xdoclet-definition --> 
	 *
	 * @ejb.persistent-field 
	 * @ejb.persistence
	 *    column-name="time_from"
     *     jdbc-type="TIME"
     *     sql-type="TIME"
	 *     read-only="false"
	 * 
	 * @ejb.pk-field 
	 *
	 * @ejb.interface-method
	 * 
	 * <!-- end-xdoclet-definition --> 
	 * @generated
	 */
	public abstract java.sql.Time getTime_from();
	
	/**
	 * <!-- begin-user-doc -->
	 * Sets the time_from
	 * 
	 * @param java.util.Date the new time_from value
	 * <!-- end-user-doc -->
	 * 
	 * <!-- begin-xdoclet-definition --> 
	 * @ejb.interface-method
	 * <!-- end-xdoclet-definition -->
	 * @generated 
	 */
	public abstract void setTime_from(java.sql.Time time_from);
	
	/**
	 *
	 *
	 * <!-- begin-user-doc -->
	 * CMP Field time_to
	 *
	 * Returns the time_to
	 * @return the time_to
	 * 
	 * <!-- end-user-doc -->
	 *
	 * <!-- begin-xdoclet-definition --> 
	 *
	 * @ejb.persistent-field 
	 * @ejb.persistence
	 *    column-name="time_to"
     *     jdbc-type="TIME"
     *     sql-type="TIME"
	 *     read-only="false"
	 * 
	 * @ejb.pk-field 
	 *
	 * @ejb.interface-method
	 * 
	 * <!-- end-xdoclet-definition --> 
	 * @generated
	 */
	public abstract java.sql.Time getTime_to();
	
	/**
	 * <!-- begin-user-doc -->
	 * Sets the time_to
	 * 
	 * @param java.util.Date the new time_to value
	 * <!-- end-user-doc -->
	 * 
	 * <!-- begin-xdoclet-definition --> 
	 * @ejb.interface-method
	 * <!-- end-xdoclet-definition -->
	 * @generated 
	 */
	public abstract void setTime_to(java.sql.Time time_to);

	/**
	 *
	 *
	 * <!-- begin-user-doc -->
	 * CMP Field description
	 *
	 * Returns the description
	 * @return the description
	 * 
	 * <!-- end-user-doc -->
	 *
	 * <!-- begin-xdoclet-definition --> 
	 *
	 * @ejb.persistent-field 
	 * @ejb.persistence
	 *    column-name="description"
	 *     jdbc-type="VARCHAR"
	 *     sql-type="VARCHAR"
	 *     read-only="false"
	 *  
	 *
	 * @ejb.interface-method
	 * 
	 * <!-- end-xdoclet-definition --> 
	 * @generated
	 */
	public abstract java.lang.String getDescription();
	
	/**
	 * <!-- begin-user-doc -->
	 * Sets the description
	 * 
	 * @param java.lang.String the new description value
	 * <!-- end-user-doc -->
	 * 
	 * <!-- begin-xdoclet-definition --> 
	 * @ejb.interface-method
	 * <!-- end-xdoclet-definition -->
	 * @generated 
	 */
	public abstract void setDescription(java.lang.String description);
	
	/**
	 *
	 *
	 * <!-- begin-user-doc -->
	 * CMP Field reg_date
	 *
	 * Returns the reg_date
	 * @return the reg_date
	 * 
	 * <!-- end-user-doc -->
	 *
	 * <!-- begin-xdoclet-definition --> 
	 *
	 * @ejb.persistent-field 
	 * @ejb.persistence
	 *    column-name="reg_date"
	 *     jdbc-type="TIMESTAMP"
	 *     sql-type="TIMESTAMP"
	 *     read-only="false"
	 *  
	 *
	 * @ejb.interface-method
	 * 
	 * <!-- end-xdoclet-definition --> 
	 * @generated
	 */
	public abstract java.util.Date getReg_date();
	
	/**
	 * <!-- begin-user-doc -->
	 * Sets the reg_date
	 * 
	 * @param java.util.Date the new reg_date value
	 * <!-- end-user-doc -->
	 * 
	 * <!-- begin-xdoclet-definition --> 
	 * @ejb.interface-method
	 * <!-- end-xdoclet-definition -->
	 * @generated 
	 */
	public abstract void setReg_date(java.util.Date reg_date);
	
	/**
	 *
	 *
	 * <!-- begin-user-doc -->
	 * CMP Field update_date
	 *
	 * Returns the update_date
	 * @return the update_date
	 * 
	 * <!-- end-user-doc -->
	 *
	 * <!-- begin-xdoclet-definition --> 
	 *
	 * @ejb.persistent-field 
	 * @ejb.persistence
	 *    column-name="update_date"
	 *     jdbc-type="TIMESTAMP"
	 *     sql-type="TIMESTAMP"
	 *     read-only="false"
	 *  
	 *
	 * @ejb.interface-method
	 * 
	 * <!-- end-xdoclet-definition --> 
	 * @generated
	 */
	public abstract java.util.Date getUpdate_date();
	
	/**
	 * <!-- begin-user-doc -->
	 * Sets the update_date
	 * 
	 * @param java.util.Date the new update_date value
	 * <!-- end-user-doc -->
	 * 
	 * <!-- begin-xdoclet-definition --> 
	 * @ejb.interface-method
	 * <!-- end-xdoclet-definition -->
	 * @generated 
	 */
	public abstract void setUpdate_date(java.util.Date update_date);
	
	/**
	 *
	 *
	 * <!-- begin-user-doc -->
	 * CMP Field reg_user
	 *
	 * Returns the reg_user
	 * @return the reg_user
	 * 
	 * <!-- end-user-doc -->
	 *
	 * <!-- begin-xdoclet-definition --> 
	 *
	 * @ejb.persistent-field 
	 * @ejb.persistence
	 *    column-name="reg_user"
	 *     jdbc-type="VARCHAR"
	 *     sql-type="VARCHAR"
	 *     read-only="false"
	 *  
	 *
	 * @ejb.interface-method
	 * 
	 * <!-- end-xdoclet-definition --> 
	 * @generated
	 */
	public abstract java.lang.String getReg_user();
	
	/**
	 * <!-- begin-user-doc -->
	 * Sets the description
	 * 
	 * @param java.lang.String the new reg_user value
	 * <!-- end-user-doc -->
	 * 
	 * <!-- begin-xdoclet-definition --> 
	 * @ejb.interface-method
	 * <!-- end-xdoclet-definition -->
	 * @generated 
	 */
	public abstract void setReg_user(java.lang.String reg_user);
	
	/**
	 *
	 *
	 * <!-- begin-user-doc -->
	 * CMP Field update_user
	 *
	 * Returns the update_user
	 * @return the update_user
	 * 
	 * <!-- end-user-doc -->
	 *
	 * <!-- begin-xdoclet-definition --> 
	 *
	 * @ejb.persistent-field 
	 * @ejb.persistence
	 *    column-name="update_user"
	 *     jdbc-type="VARCHAR"
	 *     sql-type="VARCHAR"
	 *     read-only="false"
	 *  
	 *
	 * @ejb.interface-method
	 * 
	 * <!-- end-xdoclet-definition --> 
	 * @generated
	 */
	public abstract java.lang.String getUpdate_user();
	
	/**
	 * <!-- begin-user-doc -->
	 * Sets the description
	 * 
	 * @param java.lang.String the new update_user value
	 * <!-- end-user-doc -->
	 * 
	 * <!-- begin-xdoclet-definition --> 
	 * @ejb.interface-method
	 * <!-- end-xdoclet-definition -->
	 * @generated 
	 */
	public abstract void setUpdate_user(java.lang.String update_user);
	
	//	==========================================
	//	 CMR fields
	//	==========================================
	
    /**
     * @ejb.interface-method
     *    view-type="local"
     * 
     * @ejb.relation 
     *    name="CalendarInfo-CalendarWeekdayInfo"
     *    role-name="CalendarWeekdayInfo-CalendarInfo(multi)"
     *    cascade-delete="yes"
     * 
	 * @jboss.relation
	 *    related-pk-field="calendar_id"
	 *    fk-column="calendar_id"
	 *    batch-cascade-delete="true"
     */
    public abstract CalendarInfoLocal getCalendarInfo();
    
    /**
     * 
     * @ejb.interface-method view-type="local"
     */
    public abstract void setCalendarInfo(CalendarInfoLocal calendarInfo);
}

==> hinemos_src-4.0.0.tar.gz: HinemosManager/src_calendar/com/clustercontrol/calendar/ejb/entity/CalendarWeekdayInfoBean.java <==
/*

Copyright (C) 2006 NTT DATA Corporation

This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License
as published by the Free Software Foundation, version 2.

This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
PURPOSE.  See the GNU General Public License for more details.

 */

package com.clustercontrol.calendar.ejb.entity;

import java.sql.Time;
import java.util.Date;
import java.util.Set;

import javax.ejb.FinderException;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 *
 * <!-- begin-user-doc --> カレンダーの曜日別実行規則情報のEntityBean '<em><b>CalendarWeekdayInfoBean</b></em>'. <!-- end-user-doc --> *
 *
 * <!-- begin-xdoclet-definition -->
 * @ejb.bean name="CalendarWeekdayInfo"
 *    jndi-name="CalendarWeekdayInfo"
 *    type="CMP"
 *    view-type="local"
 *    schema="CalendarWeekdayInfo"
 *    cmp-version="2.x"
 *    data-source="java:/DefaultDS"
 * 
 * @ejb.persistence
 *    table-name="cc_cal_weekday_info"
 * 
 * @ejb.pk
 *    class="com.clustercontrol.calendar.ejb.entity.CalendarWeekdayInfoPK"
 * 
 * @jboss.persistence
 *    datasource="java:/DefaultDS"
 *    datasource-mapping="PostgreSQL 8.0"
 *    table-name="public.cc_cal_weekday_info"
 *    create-table="false"
 *    remove-table="false"
 *    alter-table="false"
 * 
 * @jboss.container-configuration
 *    name="Hinemos Config CMP 2.x EntityBean"
 * 
 * @jboss.depends
 *    name="jboss.jca:service=DataSourceBinding,name=DefaultDS"
 * 
 * @ejb.permission
 *    unchecked="true"
 * 
 * @jboss.method-attributes
 *    pattern="get*"
 *    read-only="true"
 * 
 * @ejb.finder
 *    query="SELECT OBJECT(a) FROM CalendarWeekdayInfo as a"
 *    signature="java.util.Collection findAll()"
 * 
 * @ejb.finder
 *    query="SELECT OBJECT(a) FROM CalendarWeekdayInfo as a WHERE a.calendar_id = ?1"
 *    signature="java.util.Collection findByCalendarId(java.lang.String calendarId)"
 * 
 * @ejb.finder
 *    query="SELECT OBJECT(a) FROM CalendarWeekdayInfo as a WHERE a.calendar_id = ?1 AND a.weekday = ?2"
 *    signature="java.util.Collection findByWeekday(java.lang.String calendarId, java.lang.Integer weekday)"
 * 
 * @ejb.finder
 *    query="SELECT OBJECT(a) FROM CalendarWeekdayInfo as a WHERE a.calendar_id = ?1 AND a.weekday = ?2 AND ((a.time_from <= ?3 AND a.time_to >= ?3) OR (a.time_from <= ?4 AND a.time_to >= ?4))"
 *    signature="java.util.Collection findByTimeFromTo(java.lang.String calendarId, java.lang.Integer weekday, java.sql.Time from, java.sql.Time to)"
 * 
 * @ejb.select
 *    result-type-mapping= "Local"
 *    method-intf= "LocalHome"
 *    query=""
 *    signature="java.util.Collection ejbSelectGeneric(java.lang.String jbossQL, java.lang.Object[] arg)"
 * @jboss.query
 *    dynamic="true"
 *    signature="java.util.Collection ejbSelectGeneric(java.lang.String jbossQL, java.lang.Object[] arg)"
 * 
 * <!-- end-xdoclet-definition -->
 * @generated
 **/
public abstract class CalendarWeekdayInfoBean implements javax.ejb.EntityBean {
	protected static Log m_log = LogFactory.getLog( CalendarWeekdayInfoBean.class );

	/**
	 *
	 * <!-- begin-user-doc -->
	 * The  ejbCreate method.
	 * <!-- end-user-doc -->
	 *
	 * <!-- begin-xdoclet-definition -->
	 * @ejb.create-method
	 * <!-- end-xdoclet-definition -->
	 * @generated
	 */
	public CalendarWeekdayInfoPK ejbCreate(
			String calendar_id,
			Integer weekday,
			Time time_from,
			Time time_to,
			String description,
			Date reg_date,
			Date update_date,
			String reg_user,
			String update_user
	) throws javax.ejb.CreateException {
		setCalendar_id(calendar_id);
		setWeekday(weekday);
		setDescription(description);
		setTime_from(time_from);
		setTime_to(time_to);
		setReg_date(reg_date);
		setUpdate_date(update_date);
		setReg_user(reg_user);
		setUpdate_user(update_user);
		return null;
	}


	/**
	 * <!-- begin-user-doc -->
	 * The container invokes this method immediately after it calls ejbCreate.
	 * <!-- end-user-doc -->
	 * 
	 * @generated
	 */
	public void ejbPostCreate() throws javax.ejb.CreateException {
		// begin-user-code
		// end-user-code
	}

	/**
	 * DynamicQL
	 * 
	 * @param jbossQl JBossQL
	 * @param args query arguments as parameters
	 * 
	 * @jboss.dynamic-ql
	 */
	public abstract Set ejbSelectGeneric(String jbossQl, Object[] arguments) throws FinderException;

	/**
	 *
	 *
	 * <!-- begin-user-doc -->
	 * CMP Field calendar_id
	 *
	 * Returns the calendar_id
	 * @return the calendar_id
	 * 
	 * <!-- end-user-doc -->
	 *
	 * <!-- begin-xdoclet-definition -->
	 *
	 * @ejb.persistent-field
	 * @ejb.persistence
	 *    column-name="calendar_id"
	 *     jdbc-type="VARCHAR"
	 *     sql-type="VARCHAR"
	 *     read-only="false"
	 * 
	 * @ejb.pk-field
	 *
	 * @ejb.interface-method
	 * 
	 * <!-- end-xdoclet-definition -->
	 * @generated
	 */
	public abstract java.lang.String getCalendar_id();

	/**
	 * <!-- begin-user-doc -->
	 * Sets the calendar_id
	 * 
	 * @param java.lang.String the new calendar_id value
	 * <!-- end-user-doc -->
	 * 
	 * <!-- begin-xdoclet-definition -->
	 * @ejb.interface-method
	 * <!-- end-xdoclet-definition -->
	 * @generated
	 */
	public abstract void setCalendar_id(java.lang.String calendar_id);

	/**
	 *
	 *
	 * <!-- begin-user-doc -->
	 * CMP Field weekday
	 *
	 * Returns the weekday
	 * @return the weekday
	 * 
	 * <!-- end-user-doc -->
	 *
	 * <!-- begin-xdoclet-definition -->
	 *
	 * @ejb.persistent-field
	 * @ejb.persistence
	 *    column-name="weekday"
	 *     jdbc-type="SMALLINT"
	 *     sql-type="SMALLINT"
	 *     read-only="false"
	 * 
	 * @ejb.pk-field
	 *
	 * @ejb.interface-method
	 * 
	 * <!-- end-xdoclet-definition -->
	 * @generated
	 */
	public abstract java.lang.Integer getWeekday();

	/**
	 * <!-- begin-user-doc -->
	 * Sets the weekday
	 * 
	 * @param java.lang.Integer the new weekday value
	 * <!-- end-user-doc -->
	 * 
	 * <!-- begin-xdoclet-definition -->
	 * @ejb.interface-method
	 * <!-- end-xdoclet-definition -->
	 * @generated
	 */
	public abstract void setWeekday(java.lang.Integer weekday);

	/**
	 *
	 *
	 * <!-- begin-user-doc -->
	 * CMP Field time_from
	 *
	 * Returns the time_from
	 * @return the time_from
	 * 
	 * <!-- end-user-doc -->
	 *
	 * <!-- begin-xdoclet-definition -->
	 *
	 * @ejb.persistent-field
	 * @ejb.persistence
	 *    column-name="time_from"
	 *     jdbc-type="TIME"
	 *     sql-type="TIME"
	 *     read-only="false"
	 * 
	 * @ejb.pk-field
	 *
	 * @ejb.interface-method
	 * 
	 * <!-- end-xdoclet-definition -->
	 * @generated
	 */
	public abstract java.sql.Time getTime_from();

	/**
	 * <!-- begin-user-doc -->
	 * Sets the time_from
	 * 
	 * @param java.util.Date the new time_from value
	 * <!-- end-user-doc -->
	 * 
	 * <!-- begin-xdoclet-definition -->
	 * @ejb.interface-method
	 * <!-- end-xdoclet-definition -->
	 * @generated
	 */
	public abstract void setTime_from(java.sql.Time time_from);

	/**
	 *
	 *
	 * <!-- begin-user-doc -->
	 * CMP Field time_to
	 *
	 * Returns the time_to
	 * @return the time_to
	 * 
	 * <!-- end-user-doc -->
	 *
	 * <!-- begin-xdoclet-definition -->
	 *
	 * @ejb.persistent-field
	 * @ejb.persistence
	 *    column-name="time_to"
	 *     jdbc-type="TIME"
	 *     sql-type="TIME"
	 *     read-only="false"
	 * 
	 * @ejb.pk-field
	 *
	 * @ejb.interface-method
	 * 
	 * <!-- end-xdoclet-definition -->
	 * @generated
	 */
	public abstract java.sql.Time getTime_to();

	/**
	 * <!-- begin-user-doc -->
	 * Sets the time_to
	 * 
	 * @param java.util.Date the new time_to value
	 * <!-- end-user-doc -->
	 * 
	 * <!-- begin-xdoclet-definition -->
	 * @ejb.interface-method
	 * <!-- end-xdoclet-definition -->
	 * @generated
	 */
	public abstract void setTime_to(java.sql.Time time_to);

	/**
	 *
	 *
	 * <!-- begin-user-doc -->
	 * CMP Field description
	 *
	 * Returns the description
	 * @return the description
	 * 
	 * <!-- end-user-doc -->
	 *
	 * <!-- begin-xdoclet-definition -->
	 *
	 * @ejb.persistent-field
	 * @ejb.persistence
	 *    column-name="description"
	 *     jdbc-type="VARCHAR"
	 *     sql-type="VARCHAR"
	 *     read-only="false"
	 * 
	 *
	 * @ejb.interface-method
	 * 
	 * <!-- end-xdoclet-definition -->
	 * @generated
	 */
	public abstract java.lang.String getDescription();

	/**
	 * <!-- begin-user-doc -->
	 * Sets the description
	 * 
	 * @param java.lang.String the new description value
	 * <!-- end-user-doc -->
	 * 
	 * <!-- begin-xdoclet-definition -->
	 * @ejb.interface-method
	 * <!-- end-xdoclet-definition -->
	 * @generated
	 */
	public abstract void setDescription(java.lang.String description);

	/**
	 *
	 *
	 * <!-- begin-user-doc -->
	 * CMP Field reg_date
	 *
	 * Returns the reg_date
	 * @return the reg_date
	 * 
	 * <!-- end-user-doc -->
	 *
	 * <!-- begin-xdoclet-definition -->
	 *
	 * @ejb.persistent-field
	 * @ejb.persistence
	 *    column-name="reg_date"
	 *     jdbc-type="TIMESTAMP"
	 *     sql-type="TIMESTAMP"
	 *     read-only="false"
	 * 
	 *
	 * @ejb.interface-method
	 * 
	 * <!-- end-xdoclet-definition -->
	 * @generated
	 */
	public abstract java.util.Date getReg_date();

	/**
	 * <!-- begin-user-doc -->
	 * Sets the reg_date
	 * 
	 * @param java.util.Date the new reg_date value
	 * <!-- end-user-doc -->
	 * 
	 * <!-- begin-xdoclet-definition -->
	 * @ejb.interface-method
	 * <!-- end-xdoclet-definition -->
	 * @generated
	 */
	public abstract void setReg_date(java.util.Date reg_date);

	/**
	 *
	 *
	 * <!-- begin-user-doc -->
	 * CMP Field update_date
	 *
	 * Returns the update_date
	 * @return the update_date
	 * 
	 * <!-- end-user-doc -->
	 *
	 * <!-- begin-xdoclet-definition -->
	 *
	 * @ejb.persistent-field
	 * @ejb.persistence
	 *    column-name="update_date"
	 *     jdbc-type="TIMESTAMP"
	 *     sql-type="TIMESTAMP"
	 *     read-only="false"
	 * 
	 *
	 * @ejb.interface-method
	 * 
	 * <!-- end-xdoclet-definition -->
	 * @generated
	 */
	public abstract java.util.Date getUpdate_date();

	/**
	 * <!-- begin-user-doc -->
	 * Sets the update_date
	 * 
	 * @param java.util.Date the new update_date value
	 * <!-- end-user-doc -->
	 * 
	 * <!-- begin-xdoclet-definition -->
	 * @ejb.interface-method
	 * <!-- end-xdoclet-definition -->
	 * @generated
	 */
	public abstract void setUpdate_date(java.util.Date update_date);

	/**
	 *
	 *
	 * <!-- begin-user-doc -->
	 * CMP Field reg_user
	 *
	 * Returns the reg_user
	 * @return the reg_user
	 * 
	 * <!-- end-user-doc -->
	 *
	 * <!-- begin-xdoclet-definition -->
	 *
	 * @ejb.persistent-field
	 * @ejb.persistence
	 *    column-name="reg_user"
	 *     jdbc-type="VARCHAR"
	 *     sql-type="VARCHAR"
	 *     read-only="false"
	 * 
	 *
	 * @ejb.interface-method
	 * 
	 * <!-- end-xdoclet-definition -->
	 * @generated
	 */
	public abstract java.lang.String getReg_user();

	/**
	 * <!-- begin-user-doc -->
	 * Sets the description
	 * 
	 * @param java.lang.String the new reg_user value
	 * <!-- end-user-doc -->
	 * 
	 * <!-- begin-xdoclet-definition -->
	 * @ejb.interface-method
	 * <!-- end-xdoclet-definition -->
	 * @generated
	 */
	public abstract void setReg_user(java.lang.String reg_user);

	/**
	 *
	 *
	 * <!-- begin-user-doc -->
	 * CMP Field update_user
	 *
	 * Returns the update_user
	 * @return the update_user
	 * 
	 * <!-- end-user-doc -->
	 *
	 * <!-- begin-xdoclet-definition -->
	 *
	 * @ejb.persistent-field
	 * @ejb.persistence
	 *    column-name="update_user"
	 *     jdbc-type="VARCHAR"
	 *     sql-type="VARCHAR"
	 *     read-only="false"
	 * 
	 *
	 * @ejb.interface-method
	 * 
	 * <!-- end-xdoclet-definition -->
	 * @generated
	 */
	public abstract java.lang.String getUpdate_user();

	/**
	 * <!-- begin-user-doc -->
	 * Sets the description
	 * 
	 * @param java.lang.String the new update_user value
	 * <!-- end-user-doc -->
	 * 
	 * <!-- begin-xdoclet-definition -->
	 * @ejb.interface-method
	 * <!-- end-xdoclet-definition -->
	 * @generated
	 */
	public abstract void setUpdate_user(java.lang.String update_user);

	//	==========================================
	//	 CMR fields
	//	==========================================

	/**
	 * @ejb.interface-method
	 *    view-type="local"
	 * 
	 * @ejb.relation
	 *    name="CalendarInfo-CalendarWeekdayInfo"
	 *    role-name="CalendarWeekdayInfo-CalendarInfo(multi)"
	 *    cascade-delete="yes"
	 * 
	 * @jboss.relation
	 *    related-pk-field="calendar_id"
	 *    fk-column="calendar_id"
	 *    batch-cascade-delete="true"
	 */
	public abstract CalendarInfoLocal getCalendarInfo();

	/**
	 * 
	 * @ejb.interface-method view-type="local"
	 */
	public abstract void setCalendarInfo(CalendarInfoLocal calendarInfo);
}
